package Alien::LibGumbo::Install::Files;
use strict;
use warnings;
require Alien::LibGumbo;
sub Inline { shift; Alien::LibGumbo->Inline(@_) }
1;

=begin Pod::Coverage

  Inline

=end Pod::Coverage

=cut
