package Alien::LibGumbo;

use v5.10;
use strict;
use warnings;

our $VERSION = 0.05;

use parent 'Alien::Base';

=head1 NAME

Alien::LibGumbo - Gumbo parser library

=head1 DESCRIPTION

This distribution installs L<libgumbo:https://github.com/google/gumbo-parser> on your
system for use by perl modules like L<HTML::Gumbo>.

B<If you're interested in parsing HTML> then you want L<HTML::Gumbo> module, not this.

=head1 AUTHOR

Ruslan Zakirov E<lt>Ruslan.Zakirov@gmail.comE<gt>

=head1 LICENSE

Under the same terms as perl itself.

=cut

1;